# Contact Support
### On this page
  * [Submitting a Request in SAP LeanIX](https://help.sap.com/docs/leanix/ea/contact-support#submitting-a-request-in-sap-leanix)
  * [Submitting a Request in the SAP for Me Portal](https://help.sap.com/docs/leanix/ea/contact-support#submitting-a-request-in-the-sap-for-me-portal)
  * [Additional Resources](https://help.sap.com/docs/leanix/ea/contact-support#additional-resources)


If you encounter issues, have questions, or need assistance with SAP LeanIX, our support team is here to help. You can contact support directly within SAP LeanIX or submit a request in the SAP for Me portal.
